@@ -23,6 +23,7 @@ from tencentcloud.cr.v20180321 import models
 class CrClient(AbstractClient):
     _apiVersion = '2018-03-21'
     _endpoint = 'cr.tencentcloudapi.com'
+    _service = 'cr'
 
 
     def ApplyBlackList(self, request):
@@ -81,6 +82,62 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateBotTask(self, request):
+        """创建机器人任务
+
+        :param request: Request instance for CreateBotTask.
+        :type request: :class:`tencentcloud.cr.v20180321.models.CreateBotTaskRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.CreateBotTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateBotTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateBotTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeBotFlow(self, request):
+        """查询机器人对话流
+
+        :param request: Request instance for DescribeBotFlow.
+        :type request: :class:`tencentcloud.cr.v20180321.models.DescribeBotFlowRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.DescribeBotFlowResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeBotFlow", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeBotFlowResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeCreditResult(self, request):
         """根据信审任务ID和请求日期，获取相关信审结果。
 
@@ -109,6 +166,34 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeFileModel(self, request):
+        """查询机器人文件模板
+
+        :param request: Request instance for DescribeFileModel.
+        :type request: :class:`tencentcloud.cr.v20180321.models.DescribeFileModelRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.DescribeFileModelResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeFileModel", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeFileModelResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRecords(self, request):
         """用于获取指定案件的录音地址，次日早上8:00后可查询前日录音。
 
@@ -250,6 +335,34 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ExportBotData(self, request):
+        """导出机器人数据
+
+        :param request: Request instance for ExportBotData.
+        :type request: :class:`tencentcloud.cr.v20180321.models.ExportBotDataRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.ExportBotDataResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ExportBotData", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ExportBotDataResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def QueryInstantData(self, request):
         """实时数据查询
 
@@ -278,6 +391,62 @@ class CrClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def QueryProducts(self, request):
+        """查询产品列表
+
+        :param request: Request instance for QueryProducts.
+        :type request: :class:`tencentcloud.cr.v20180321.models.QueryProductsRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.QueryProductsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("QueryProducts", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.QueryProductsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def UploadBotFile(self, request):
+        """上传机器人文件
+
+        :param request: Request instance for UploadBotFile.
+        :type request: :class:`tencentcloud.cr.v20180321.models.UploadBotFileRequest`
+        :rtype: :class:`tencentcloud.cr.v20180321.models.UploadBotFileResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("UploadBotFile", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.UploadBotFileResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UploadDataFile(self, request):
         """上传文件，接口返回数据任务ID，支持xlsx、xls、csv、zip格式。
 
